@@ -5,7 +5,7 @@ package WWW::Sitemap::XML;
 BEGIN {
   $WWW::Sitemap::XML::AUTHORITY = 'cpan:AJGB';
 }
-$WWW::Sitemap::XML::VERSION = '2.00';
+$WWW::Sitemap::XML::VERSION = '2.01';
 use Moose;
 
 use WWW::Sitemap::XML::URL;
@@ -254,7 +254,7 @@ WWW::Sitemap::XML - XML Sitemap protocol
 
 =head1 VERSION
 
-version 2.00
+version 2.01
 
 =head1 SYNOPSIS
 
@@ -275,14 +275,14 @@ version 2.00
         images => [
             {
                 loc => 'http://mywebsite.com/image1.jpg',
-                caption => Caption 1',
+                caption => 'Caption 1',
                 title => 'Title 1',
                 license => 'http://www.mozilla.org/MPL/2.0/',
                 geo_location => 'Town, Region',
             },
             {
                 loc => 'http://mywebsite.com/image2.jpg',
-                caption => Caption 2',
+                caption => 'Caption 2',
                 title => 'Title 2',
                 license => 'http://www.mozilla.org/MPL/2.0/',
                 geo_location => 'Town, Region',
@@ -367,7 +367,7 @@ version 2.00
 =head1 DESCRIPTION
 
 Read and write sitemap XML files as defined at L<http://www.sitemaps.org/> and
-with support of Google video and image extensions described at L<https://support.google.com/webmasters/answer/183668>.
+with support of Google video, image and mobile extensions described at L<https://support.google.com/webmasters/answer/183668>.
 
 =head1 METHODS
 
