@@ -5,7 +5,7 @@ package WWW::Sitemap::XML::URL;
 BEGIN {
   $WWW::Sitemap::XML::URL::AUTHORITY = 'cpan:AJGB';
 }
-$WWW::Sitemap::XML::URL::VERSION = '2.00';
+$WWW::Sitemap::XML::URL::VERSION = '2.01';
 use Moose;
 use WWW::Sitemap::XML::Types qw( Location ChangeFreq Priority ArrayRefOfImageObjects ArrayRefOfVideoObjects );
 use MooseX::Types::DateTime::W3C qw( DateTimeW3C );
@@ -144,7 +144,7 @@ WWW::Sitemap::XML::URL - XML Sitemap url entry
 
 =head1 VERSION
 
-version 2.00
+version 2.01
 
 =head1 SYNOPSIS
 
@@ -167,7 +167,7 @@ XML output:
        </url>
     </urlset>
 
-Google sitemap video and image extensions:
+Google sitemap video, image and mobile extensions:
 
     my $url2 = WWW::Sitemap::XML::URL->new(
         loc => 'http://mywebsite.com/',
@@ -178,14 +178,14 @@ Google sitemap video and image extensions:
         images => [
             {
                 loc => 'http://mywebsite.com/image1.jpg',
-                caption => Caption 1',
+                caption => 'Caption 1',
                 title => 'Title 1',
                 license => 'http://www.mozilla.org/MPL/2.0/',
                 geo_location => 'Town, Region',
             },
             {
                 loc => 'http://mywebsite.com/image2.jpg',
-                caption => Caption 2',
+                caption => 'Caption 2',
                 title => 'Title 2',
                 license => 'http://www.mozilla.org/MPL/2.0/',
                 geo_location => 'Town, Region',
@@ -209,6 +209,7 @@ XML output:
 
     <?xml version="1.0" encoding="UTF-8"?>
     <urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9"
+        xmlns:mobile="http://www.google.com/schemas/sitemap-mobile/1.0"
         xmlns:image="http://www.google.com/schemas/sitemap-image/1.1"
         xmlns:video="http://www.google.com/schemas/sitemap-video/1.1">
        <url>
@@ -252,8 +253,6 @@ Class implements L<WWW::Sitemap::XML::URL::Interface>.
 
 =head2 loc
 
-    $url->loc('http://mywebsite.com/')
-
 URL of the page.
 
 isa: L<WWW::Sitemap::XML::Types/"Location">
@@ -314,7 +313,7 @@ non-featurephone content, create a separate sitemap for those URLs.
 
 Note: This is a Google sitemap extension.
 
-isa: I<Bool>
+isa: C<Bool>
 
 Optional.
 
@@ -328,6 +327,12 @@ Returns L<XML::LibXML::Element> object representing the C<E<lt>urlE<gt>> entry i
 
 L<http://www.sitemaps.org/protocol.php>
 
+L<WWW::Sitemap::XML::Google::Image>
+
+L<WWW::Sitemap::XML::Google::Video>
+
+L<https://support.google.com/webmasters/answer/183668>
+
 =head1 AUTHOR
 
 Alex J. G. Burzyński <ajgb@cpan.org>
